@@ -169,11 +169,17 @@ class Scenario(Term):
             - Tau will be fixed as the last phase's value.
             - kwargs: Default values are the parameter values of the last phase.
         """
-        self._ensure_name(name)
-        self._series_dict[name].add(
-            end_date=end_date, days=days, population=population,
-            model=model, tau=self.tau, **kwargs
-        )
+        series = self._ensure_name(name)
+        try:
+            self._series_dict[name].add(
+                end_date=end_date, days=days, population=population,
+                model=model, tau=self.tau, **kwargs
+            )
+        except ValueError:
+            last_date = series.unit("last").end_date
+            s1 = f'For "{name}" scenario, @end_date needs to match "DDMmmYYYY" format'
+            raise ValueError(
+                f'{s1} and be over {last_date}. However, {end_date} was applied.') from None
         return self
 
     def _ensure_name(self, name, template="Main"):
@@ -347,7 +353,7 @@ class Scenario(Term):
 
         Args:
             date (str): change point, i.e. start date of the new phase
-            name (str, optional): name of phase series
+            name (str): scenario name
             population (int): population value of the change point
             kwargs: keyword arguments of PhaseUnit.set_ode()
 
@@ -360,8 +366,12 @@ class Scenario(Term):
                 (self.num2str(i), unit) for (i, unit) in enumerate(series) if date in unit][0]
         except IndexError:
             raise IndexError(f"Phase on @date ({date}) is not registered.")
-        new_pre = PhaseUnit(
-            old.start_date, self.yesterday(date), old.population)
+        try:
+            new_pre = PhaseUnit(
+                old.start_date, self.yesterday(date), old.population)
+        except ValueError:
+            raise ValueError(
+                f"{name} scenario cannot be separated on {date} because this date is registered as a start date.") from None
         new_pre.set_ode(**old.to_dict())
         new_fol = PhaseUnit(date, old.end_date, population or old.population)
         new_fol.set_ode(**kwargs)
@@ -605,7 +615,7 @@ class Scenario(Term):
                     - Date (pd.TimeStamp): Observation date
                     - Country (str): country/region name
                     - Province (str): province/prefecture/state name
-                    - variables of the models (int): Confirmed (int) etc.
+                    - Variables of the model and dataset (int): Confirmed etc.
         """
         series = self._ensure_name(name)
         # Simulation
@@ -732,6 +742,53 @@ class Scenario(Term):
         )
         return df
 
+    def _describe(self, y0_dict=None):
+        """
+        Describe representative values.
+
+        Args:
+            y0_dict (dict or None): dictionary of initial values or None
+                - key (str): variable name
+                - value (float): initial value
+
+        Returns:
+            (pandas.DataFrame)
+                Index:
+                    (int): scenario name
+                Columns:
+                    - max(Infected): max value of Infected
+                    - argmax(Infected): the date when Infected shows max value
+                    - Confirmed({date}): Confirmed on the next date of the last phase
+                    - Infected({date}): Infected on the next date of the last phase
+                    - Fatal({date}): Fatal on the next date of the last phase
+        """
+        _dict = {}
+        for (name, _) in self._series_dict.items():
+            # Predict the number of cases
+            df = self.simulate(name=name, y0_dict=y0_dict, show_figure=False)
+            df = df.set_index(self.DATE)
+            cols = df.columns[:]
+            last_date = df.index[-1]
+            # Max value of Infected
+            max_ci = df[self.CI].max()
+            argmax_ci = df[self.CI].idxmax().strftime(self.DATE_FORMAT)
+            # Confirmed on the next date of the last phase
+            last_c = df.loc[last_date, self.C]
+            # Infected on the next date of the last phase
+            last_ci = df.loc[last_date, self.CI]
+            # Fatal on the next date of the last phase
+            last_f = df.loc[last_date, self.F] if self.F in cols else None
+            # Save representative values
+            last_date_str = last_date.strftime(self.DATE_FORMAT)
+            _dict[name] = {
+                f"max({self.CI})": max_ci,
+                f"argmax({self.CI})": argmax_ci,
+                f"{self.C} on {last_date_str}": last_c,
+                f"{self.CI} on {last_date_str}": last_ci,
+                f"{self.F} on {last_date_str}": last_f,
+            }
+        return pd.DataFrame.from_dict(_dict, orient="index")
+
     def describe(self, y0_dict=None, with_rt=True):
         """
         Describe representative values.
@@ -749,42 +806,22 @@ class Scenario(Term):
                 Columns:
                     - max(Infected): max value of Infected
                     - argmax(Infected): the date when Infected shows max value
-                    - Infected({date}): Infected on the end date of the last phase
-                    - Fatal({date}): Fatal on the end date of the last phase
+                    - Confirmed({date}): Confirmed on the next date of the last phase
+                    - Infected({date}): Infected on the next date of the last phase
+                    - Fatal({date}): Fatal on the next date of the last phase
+                    - nth_Rt etc.: Rt value if the values are not the same values
         """
-        _dict = {}
-        for (name, _) in self._series_dict.items():
-            # Predict the number of cases
-            df = self.simulate(name=name, y0_dict=y0_dict, show_figure=False)
-            df = df.set_index(self.DATE)
-            cols = df.columns[:]
-            last_date = df.index[-1]
-            # Max value of Infected
-            max_ci = df[self.CI].max()
-            argmax_ci = df[self.CI].idxmax().strftime(self.DATE_FORMAT)
-            # Infected on the end date of the last phase
-            last_ci = df.loc[last_date, self.CI]
-            # Fatal on the end date of the last phase
-            last_f = df.loc[last_date, self.F] if self.F in cols else None
-            # Save representative values
-            _dict[name] = {
-                f"max({self.CI})": max_ci,
-                f"argmax({self.CI})": argmax_ci,
-                f"{self.CI} on {last_date.strftime(self.DATE_FORMAT)}": last_ci,
-                f"{self.F} on {last_date.strftime(self.DATE_FORMAT)}": last_f,
-            }
-        desc_df = pd.DataFrame.from_dict(_dict, orient="index")
+        df = self._describe(y0_dict=None)
+        if not with_rt or len(self._series_dict) == 1:
+            return df
         # History of reproduction number
-        if with_rt and len(self._series_dict) > 1:
-            rt_df = self.summary().reset_index()
-            rt_df = rt_df.pivot_table(
-                index=self.SERIES, columns=self.PHASE, values=self.RT)
-            rt_df = rt_df.fillna(self.UNKNOWN)
-            rt_df = rt_df.loc[:, rt_df.nunique() > 1]
-            cols = sorted(rt_df, key=self.str2num)
-            desc_df = desc_df.join(
-                rt_df[cols].add_suffix(f"_{self.RT}"), how="left")
-        return desc_df
+        rt_df = self.summary().reset_index()
+        rt_df = rt_df.pivot_table(
+            index=self.SERIES, columns=self.PHASE, values=self.RT)
+        rt_df = rt_df.fillna(self.UNKNOWN)
+        rt_df = rt_df.loc[:, rt_df.nunique() > 1]
+        cols = sorted(rt_df, key=self.str2num)
+        return df.join(rt_df[cols].add_suffix(f"_{self.RT}"), how="left")
 
     def _track_param(self, name):
         """
@@ -902,11 +939,78 @@ class Scenario(Term):
         if show_figure:
             series = self._series_dict["Main"]
             change_dates = [unit.start_date for unit in series][1:]
+            title = f"{self.area}: {self.RT_FULL if target == self.RT else target} over time"
             line_plot(
-                df, f"{self.area}: {target} over time", ylabel=target,
+                df, title, ylabel=target,
                 h=1.0 if target == self.RT else None,
                 v=change_dates,
                 math_scale=False,
                 filename=filename
             )
         return df
+
+    def history_rate(self, params=None, name="Main", show_figure=True, filename=None):
+        """
+        Show change rates of parameter values in one figure.
+        We can find the parameters which increased/decreased significantly.
+
+        Args:
+            params (list[str] or None): parameters to show
+            name (str): phase series name
+            show_figure (bool): If True, show the result as a figure
+            filename (str): filename of the figure, or None (show figure)
+        """
+        df = self._track_param(name=name)
+        model = self._series_dict[name].unit("last").model
+        cols = list(set(df.columns) & set(model.PARAMETERS))
+        if params is not None:
+            if not isinstance(params, (list, set)):
+                raise TypeError(
+                    f"@params must be a list of parameters, but {params} were applied.")
+            cols = list(set(cols) & set(params)) or cols
+        df = df.loc[:, cols] / df.loc[df.index[0], cols]
+        if show_figure:
+            series = self._series_dict[name]
+            change_dates = [unit.start_date for unit in series][1:]
+            f_date = df.index[0].strftime(self.DATE_FORMAT)
+            title = f"{self.area}: {model.NAME} parameter change rates over time (1.0 on {f_date})"
+            ylabel = f"Value per that on {f_date}"
+            line_plot(
+                df, title, ylabel=ylabel, v=change_dates, math_scale=False, filename=filename
+            )
+        return df
+
+    def retrospective(self, beginning_date, model, control="Main", target="Target", **args):
+        """
+        Perform retrospective analysis.
+        Compare the actual series of phases (control) and
+        series of phases with specified parameters (target).
+
+        Args:
+            beginning_date (str): when the parameter values start to be changed from actual values
+            model (covsirphy.ModelBase): ODE model
+            control (str): scenario name of control
+            target (str): scenario name of target
+            **args: keyword argument of parameters
+
+        Notes:
+            When parameter values are not specified,
+            actual values of the last date before the beginning date will be used.
+        """
+        # Control
+        self.clear(name=control, include_past=True)
+        self.trend(name=control, show_figure=False)
+        series = self._series_dict[control]
+        sep_dates = [[ph.start_date, ph.end_date] for ph in series]
+        if beginning_date not in self.flatten(sep_dates):
+            self.separate(beginning_date, name=control)
+        self.estimate(model, name=control)
+        # Target
+        self.clear(name=target, include_past=False, template=control)
+        phases_changed = [
+            self.num2str(i) for (i, ph) in enumerate(self._series_dict[target])
+            if ph >= beginning_date
+        ]
+        self.delete(phases_changed, name=target)
+        self.add(name=target, **args)
+        self.estimate(model, name=target)
