@@ -31,8 +31,8 @@ class SIRF(ModelBase):
         "w": ModelBase.F
     }
     VARIABLES = list(VAR_DICT.values())
-    # Priorities of the variables when optimization
-    PRIORITIES = np.array([1, 10, 10, 2])
+    # Weights of variables in parameter estimation error function
+    WEIGHTS = np.array([1, 1, 1, 1])
     # Variables that increases monotonically
     VARS_INCLEASE = [ModelBase.R, ModelBase.F]
     # Example set of parameters and initial values
